@@ -109,6 +109,7 @@ it under the same terms as Perl itself.
 
 =head1 SEE ALSO
 
-L<Image::ExifTool|Image::ExifTool>
+L<Image::ExifTool::TagNames/PrintIM Tags>,
+L<Image::ExifTool(3pm)|Image::ExifTool>
 
 =cut
